Learn R Programming

Rga4gh (version 0.1.1)

get_ga4gh: GET an Object

Description

GET an object from the GA4GH API

Usage

get_ga4gh(object, ...)
"get_ga4gh"(object, operation, id, ...)
"get_ga4gh"(object, operation, id, port = NULL, ...)
"get_ga4gh"(object, operation, id, ...)

Arguments

object
An object to GET from. I.e. A ga4ghClient object, a url for the server or a list of either.
...
Arguments to pass to other methods
operation
The name of the operation. Eg "datasets"
id
The ID of the Object
port
The port number

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# 
# ## Use the client and get an object from the api
# ref_client %>% get_ga4gh("datasets", "id")
# 
# ## Or provide the API location as a string
# get_ga4gh("http://1kgenomes.ga4gh.org", "datasets", "id")
# ## End(Not run)

Run the code above in your browser using DataLab