Learn R Programming

Rga4gh (version 0.1.1)

search_call_sets: Search for Call Sets

Description

Search for Call Sets

Usage

search_call_sets(client, variant_set_id = NULL, bio_sample_id = NULL, name = NULL, page_size = NULL, page_token = NULL)

Arguments

client
A ga4gh_client object
variant_set_id
The ID of the Variant Set to search within
bio_sample_id
Return only call sets generated from the provided BioSample ID.
name
Only return call sets with this name (case-sensitive, exact match).
page_size
Specifies the maximum number of results to return in a single page. If unspecified, the client default will be used.
page_token
The continuation token, which is used to page through large result sets. To get the next page of results, set this parameter to the value of nextPageToken from the previous response.

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# library(magrittr)
# ## Find a dataset to search in
# datasets <- ref_client %>% search_datasets() %>% content()
# d_id <- datasets$datasets[[1]]$id
# 
# ## Find a variant set to search in
# variant_sets <- ref_client %>% search_variant_sets(d_id) %>% content()
# vs_id <- variant_sets$variantSets[[1]]$id
# 
# ## Search for call sets in the variant set
# call_sets <- ref_client %>% search_call_sets(vs_id) %>% content()
# call_sets
# 
# ## End(Not run)

Run the code above in your browser using DataLab