Learn R Programming

Rga4gh (version 0.1.1)

search_datasets: Search for Datasets

Description

Search for Datasets

Usage

search_datasets(client, page_size = NULL, page_token = NULL)

Arguments

client
A ga4gh_client object
page_size
Specifies the maximum number of results to return in a single page. If unspecified, the client default will be used.
page_token
The continuation token, which is used to page through large result sets. To get the next page of results, set this parameter to the value of nextPageToken from the previous response.

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# ## Use the client to search for datasets
# library(magrittr)
# datasets <- ref_client %>% search_datasets() %>% content()
# datasets
# 
# ## Or specify the API location within search_datasets
# search_datasets("http://1kgenomes.ga4gh.org")
# 
# 
# ## End(Not run)

Run the code above in your browser using DataLab