Learn R Programming

Rga4gh (version 0.1.1)

search_expression_levels: Search for Expression Levels

Description

Search for Expression Levels

Usage

search_expression_levels(client, rna_quantification_id = NULL, feature_ids = NULL, threshold = NULL, page_size = NULL, page_token = NULL)

Arguments

client
A ga4gh_client object
rna_quantification_id
The ID of the RNA Quantification to search within
feature_ids
A list of Feature IDs. Only return expressions with any of the specified feature_ids.
threshold
Number
page_size
Specifies the maximum number of results to return in a single page. If unspecified, the client default will be used.
page_token
The continuation token, which is used to page through large result sets. To get the next page of results, set this parameter to the value of nextPageToken from the previous response.

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# 
# library(magrittr)
# ## Find a dataset to search in
# datasets <- ref_client %>% search_datasets() %>% content()
# d_id <- datasets$datasets[[1]]$id
# 
# ## Find an rna quantification set to search in
# rna_quantification_sets <- ref_client %>%
#  search_rna_quantification_sets(d_id) %>% content()
# rqs_id <- rna_quantification_sets$rnaQuantificationSets[[1]]$id
# 
# ## Find an rna quantification to search in
# rna_quantifications <- ref_client %>%
#  search_rna_quantifications(rqs_id) %>% content()
# rq_id <- rna_quantifications$rnaQuantifications[[1]]$id
# 
# ## Search for expression levels in the rna quantification
# expression_levels <- ref_client %>%
#  search_expression_levels(rq_id) %>% content()
# expression_levels
# 
# ## End(Not run)

Run the code above in your browser using DataLab