Learn R Programming

Rga4gh (version 0.1.1)

search_phenotypes: Search for Phenotypes

Description

Search for Phenotypes

Usage

search_phenotypes(client, phenotype_association_set_id = NULL, description = NULL, id = NULL, qualifiers = NULL, type = NULL, age_of_onset = NULL, page_size = NULL, page_token = NULL)

Arguments

client
A ga4gh_client object
phenotype_association_set_id
The ID of Phenotype Association Set to search within
description
String
id
String
qualifiers
A data.frame with columns id, sourceName, sourceVersion, term.
type
A named list with names id, sourceName, sourceVersion, term. Only return results that match this type
age_of_onset
A named list with names id, sourceName, sourceVersion, term. Only return results that match this age_of_onset
page_size
Specifies the maximum number of results to return in a single page. If unspecified, the client default will be used.
page_token
The continuation token, which is used to page through large result sets. To get the next page of results, set this parameter to the value of nextPageToken from the previous response.

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# library(magrittr)
# ## Find a dataset to search in
# datasets <- ref_client %>% search_datasets() %>% content()
# d_id <- datasets$datasets[[1]]$id
# 
# ## Find a phenotype association set to search in
# phenotype_association_sets <- ref_client %>%
#  search_phenotype_association_sets(d_id) %>% content()
# pas_id <- phenotype_association_sets$phenotypeAssociationSets[[1]]$id
# 
# ## Search for pheotypes in the phenotype association set
# phenotypes <- ref_client %>% search_phenotypes(pas_id) %>% content()
# phenotypes$phenotypes[[1]]
# 
# ## End(Not run)

Run the code above in your browser using DataLab