Learn R Programming

Rga4gh (version 0.1.1)

search_rna_quantification_sets: Search for RNA Quantification Sets

Description

Search for RNA Quantification Sets

Usage

search_rna_quantification_sets(client, dataset_id = NULL, page_size = NULL, page_token = NULL)

Arguments

client
A ga4gh_client object
dataset_id
The ID of the Dataset to search within
page_size
Specifies the maximum number of results to return in a single page. If unspecified, the client default will be used.
page_token
The continuation token, which is used to page through large result sets. To get the next page of results, set this parameter to the value of nextPageToken from the previous response.

Examples

Run this code

ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")

## Not run: 
# 
# library(magrittr)
# ## Find a dataset to search in
# datasets <- ref_client %>% search_datasets() %>% content()
# d_id <- datasets$datasets[[1]]$id
# 
# ## Search for rna quantification sets in the dataset
# rna_quantification_sets <- ref_client %>%
#  search_rna_quantification_sets(d_id) %>% content()
# rna_quantification_sets
# 
# ## End(Not run)

Run the code above in your browser using DataLab