## Create a client for the reference server at http://1kgenomes.ga4gh.org
ref_client <- ga4gh_client("http://1kgenomes.ga4gh.org", api_location = "")
## Not run:
# ## Use this client as the first argument in the high-level API functions
#
# ## Search for datasets in this server
# library(magrittr)
# datasets <- ref_client %>% search_datasets() %>% content()
#
# ## or specify the api location in the search function
# search_datasets("http://1kgenomes.ga4gh.org")
# ## End(Not run)
Run the code above in your browser using DataLab